@@ -89,7 +89,7 @@ def main():
     root_path = args.root_path[0] if args.root_path else None
 
     enable_logging = False
-    if args.v:
+    if args.verbose:
         logging_level = logging.INFO
         enable_logging = True
     elif args.vv:
