@@ -37,7 +37,6 @@ INF_ENGINE_DEFAULT_ROOT_DIRECTORY = "/usr/local/InfEngine"
 INF_ENGINE_SERVER_CONFIG = INF_ENGINE_PATH_CONF + "InfServer.conf"
 AP_PROCESS_SERVER_CONFIG = INF_ENGINE_PATH_CONF + "ap-process-server.conf"
 INF_ENGINE_COMPILER_CONFIG = INF_ENGINE_PATH_CONF + "InfCompiler.conf"
-INF_ENGINE_ENVIRONMENT_CONFIG = INF_ENGINE_PATH_CONF + "Environment.conf"
 INF_ENGINE_ELLIPSIS_COMPILER_CONFIG = INF_ENGINE_PATH_CONF + "EllipsisCompiler.conf"
 
 # Binaries paths.
@@ -49,10 +48,6 @@ INF_ENGINE_LOCK_FILE = INF_ENGINE_PATH_TMP + "BuildEngine.lock"
 # Log file.
 INF_ENGINE_LOG_FILE_PATH = INF_ENGINE_PATH_LOGS + "InfEngine.log"
 
-# Default config values.
-DEFAULT_ENVIRONMENT_CLEAN_RELEASES = 1
-DEFAULT_ENVIRONMENT_CLEAN_ENGINES = 1
-
 # Default memcached server.
 DEFAULT_INF_SERVER_CACHE_SERVERS = "localhost:11211"
 
@@ -81,7 +76,6 @@ class InfEngineServer:
                 Path(self.root_path / INF_ENGINE_SERVER_CONFIG).is_file()
                 or Path(self.root_path / AP_PROCESS_SERVER_CONFIG).is_file()
                 or Path(self.root_path / INF_ENGINE_COMPILER_CONFIG).is_file()
-                or Path(self.root_path / INF_ENGINE_ENVIRONMENT_CONFIG).is_file()
             ):
                 self.root_path = Path(INF_ENGINE_DEFAULT_ROOT_DIRECTORY)
 
@@ -129,8 +123,7 @@ class InfEngineServer:
         :param config_type: Config type. Can be:
          'inf_server',
          'inf_compiler',
-         'process_server',
-         'environment'.
+         'process_server'
         :param force: Force config re-load if it exists.
         :return: Config dict.
         """
@@ -150,15 +143,13 @@ class InfEngineServer:
             config_path = self.root_path / INF_ENGINE_COMPILER_CONFIG
         elif config_type == "process_server":
             config_path = self.root_path / AP_PROCESS_SERVER_CONFIG
-        elif config_type == "environment":
-            config_path = self.root_path / INF_ENGINE_ENVIRONMENT_CONFIG
 
         self._logger.debug(f"Config path: {config_path}.")
 
         # Read config
         # TODO: Formatting dependant config parsing. Should change later.
         config = {}
-        if config_type in ["inf_server", "inf_compiler", "environment"]:
+        if config_type in ["inf_server", "inf_compiler"]:
             with Path(config_path).open("r") as f:
                 lines = f.read().replace("// ", "#")
 
@@ -189,18 +180,6 @@ class InfEngineServer:
             pass
         elif config_type == "process_server":
             config["PidFile"] = Path(self.root_path / str(config["PidFile"]))
-        elif config_type == "environment":
-            if "Clean" in config:
-                if "releases" not in config["Clean"]:
-                    config["Clean"]["releases"] = DEFAULT_ENVIRONMENT_CLEAN_RELEASES
-
-                if "engines" not in config["Clean"]:
-                    config["Clean"]["engines"] = DEFAULT_ENVIRONMENT_CLEAN_ENGINES
-            else:
-                config["Clean"] = {
-                    "releases": DEFAULT_ENVIRONMENT_CLEAN_RELEASES,
-                    "engines": DEFAULT_ENVIRONMENT_CLEAN_ENGINES,
-                }
 
         self._logger.debug(f"Config: {config}")
         self._config[config_type] = config
@@ -258,35 +237,6 @@ class InfEngineServer:
 
         return self._check(pid)
 
-    # def _clean(self, dir: Path, exclude: list = None, limit: int = None):
-    #     counter = 0
-    #
-    #     if not dir.is_dir():
-    #         return counter
-    #
-    #     files = []
-    #     for file in dir.iterdir():
-    #         pass
-
-    # def clean(self):
-    #     """ Clean old releases, DL/ellipsis data and engines. """
-    #
-    #     self._logger.info("Cleaning InfServers.")
-    #
-    #     config = self._load_config("environment")
-    #
-    #     # Clean engines
-    #     """
-    #     # Clean engines.
-    #     my $count = _clean(
-    #             $self->{root_path} + INF_ENGINE_PATH_ENGINES,
-    #             $self->{root_path} + INF_ENGINE_LINK_READY,
-    #             $config->get( 'Clean', 'Engines' ) );
-    #     if( $count ) {
-    #         INFO "Deleted $count engines.";
-    #     };
-    #     """
-
     def start(self):
         """ Start InfEngine server. """
 
@@ -413,48 +363,6 @@ class InfEngineServer:
         else:
             return "NOT RUNNING"
 
-    def clean(self):
-        """ Delete useless data. """
-
-        self._logger.info(f"Cleaning InfServers...")
-
-        config = self._load_config("environment")
-
-        count = self._clean(
-            self.root_path / INF_ENGINE_PATH_ENGINES,
-            self.root_path / INF_ENGINE_LINK_READY,
-            int(config["Clean"]["engines"]),
-        )
-
-        if count:
-            self._logger.info(f"Deleted {count} engines.")
-
-        count = self._clean(
-            self.root_path / INF_ENGINE_PATH_RELEASES,
-            self.root_path / INF_ENGINE_LINK_RELEASE,
-            int(config["Clean"]["releases"]),
-        )
-
-        if count:
-            self._logger.info(f"Deleted {count} releases.")
-
-    def _clean(self, directory: Path, ignore: Path, limit: int = 0) -> int:
-        """ Delete several directories from the passed directory. """
-
-        counter = 0
-
-        if directory.is_dir():
-            for obj in directory.iterdir():
-                if limit - counter <= 0:
-                    break
-
-                if obj != ignore and obj.is_dir():
-                    self._logger.debug(obj)
-
-                    counter += 1
-
-        return counter
-
     def update_data(
         self,
         dldata: str = None,
@@ -507,7 +415,6 @@ class InfEngineServer:
         engine.install(dldata, dlsources, db_name=db_name)
 
         shutil.rmtree(temp_dir_path)
-        self.clean()
         self.restart()
 
     def delete_dl(self, database_name):
